@@ -697,7 +697,7 @@ class acidoBasicMainWindow(QMainWindow):
         """
         self.pngFile=os.path.join('/usr/share/pyacidobasic/pyacidobasic/icons', self.indicators[self.ui.comboBox_indicator1.currentIndex()])
         img=PIL.Image.open(self.pngFile)
-        imgArray=np.fromstring(img.tobytes(), dtype=np.uint8)
+        imgArray=np.frombuffer(img.tobytes(), dtype=np.uint8)
         imgArray=imgArray.reshape((img.size[1], img.size[0], 4))
         self.indic.setImage(image=imgArray)
         self.indic.setRect(QRectF(0,0,self.ui.plotpH.plotItem.vb.width(),14))
